import withLayout from '@/layouts'
import Taro from '@tarojs/taro'
import CustomNav from '@/components/CustomNav'
import { useEffect, useState } from "react"
import { Button, Label } from '@tarojs/components'
import { saveRoom, getRoomDetail, updateRoom } from '@/services/landlord'
import { getExtendContent } from "@/services/home";
import Extend from "../../components/Extend";
import './addRoom.less'


export default withLayout((props) => {
  const { hotelId, hotelName, roomId } = props.router.params
  const [roomModel, setRoomModel] = useState({
    hotelId,
    roomName: '',
    address: '',
    location: '',
    parkingAddress: '',
    parkingLocation: '',
    wifiName: '',
    wifiPassword: '',
    weight: '',
  })
  const onRoomMap = () => {
    Taro.chooseLocation().then((res) => {
      setRoomModel({ ...roomModel, location: res.longitude + ',' + res.latitude })

    })
  }
  const onParkMap = () => {
    Taro.chooseLocation().then((res) => {
      setRoomModel({ ...roomModel, parkingLocation: res.longitude + ',' + res.latitude })

    })
  }
  const sumbit = () => {
    if (
      roomModel.roomName != '' &&
      roomModel.address != '' &&
      roomModel.location != '' &&
      roomModel.weight != ''
    ) {
      const seveices = roomId ? updateRoom : saveRoom
      seveices(roomModel, roomId).then(() => {
        Taro.showModal({
          title: roomId ? '修改成功' : '保存成功',
          showCancel: false
        }).then(() => {
          Taro.navigateBack()
        })
      })
    } else {
      Taro.showToast({
        title: '有必填项未填哦',
        icon: 'none',
      })
    }
  }
  const [extend, setExtend] = useState([]);

  useEffect(() => {
    if (roomId) {
      getRoomDetail(roomId).then((res) => {
        setRoomModel(res)
      })
      getExtendContent('room', roomId).then((res) => {
        setExtend(res.records || []);
      })
    }
  }, [roomId])//这个地方写这个单词的目的是   因为编辑时roomId有可能还没加载成功



  return (
    <view className='page-index'>
      <view className="index-navbar">
        <CustomNav title={hotelName} />
      </view>
      <view className='from-room' style={{ height: '100%', overflow: "hidden", }} >
        <scroll-view scrollY style={{ height: '100%' }}>
          <mp-form models={roomModel} >
            <mp-cells title='房屋名称' footer='  ' >
              <mp-cell extClass='font'>
                <input onInput={(e) => setRoomModel({ ...roomModel, roomName: e.detail.value })} value={roomModel.roomName} placeholder='请输入房屋名称（必填）' />
              </mp-cell>
            </mp-cells>
            <mp-cells title='房屋位置'>
              <mp-cell extClass='font'>
                <input onInput={(e) => setRoomModel({ ...roomModel, address: e.detail.value })} value={roomModel.address} placeholder='请输入房屋位置（必填）' />
              </mp-cell>
              <mp-cell extClass='font'>
                <label onClick={onRoomMap}>{roomModel.location == '' ? '房间定位（必填）' : roomModel.location}</label>
              </mp-cell>
              </mp-cells>
            <mp-cells title='停车场位置'>
              <mp-cell extClass='font'>
                <input onInput={(e) => setRoomModel({ ...roomModel, parkingAddress: e.detail.value })} value={roomModel.parkingAddress} placeholder='请输入停车场位置' />
              </mp-cell>
              <mp-cell title='停车场经纬度：' extClass='font'>
                <label onClick={onParkMap}>{roomModel.parkingLocation == '' ? '停车场定位' : roomModel.parkingLocation}</label>
              </mp-cell>              
              </mp-cells>
            <mp-cells title='WiFi'>
              <mp-cell title='Wi-Fi名称：' extClass='font'>
                <input onInput={(e) => setRoomModel({ ...roomModel, wifiName: e.detail.value })} value={roomModel.wifiName} placeholder='请输入wifi名称' />
              </mp-cell>
              <mp-cell title='Wi-Fi密码：' extClass='font'>
                <input onInput={(e) => setRoomModel({ ...roomModel, wifiPassword: e.detail.value })} value={roomModel.wifiPassword} placeholder='请输入wifi密码' />
              </mp-cell>                          
              </mp-cells>
            <mp-cells title='权重'>
              <mp-cell  extClass='font'>
                <input type='number' value={roomModel.weight} onInput={(e) => setRoomModel({ ...roomModel, weight: e.detail.value })} placeholder='请输入权重（必填）' />
              </mp-cell>
                             
              </mp-cells>
            <mp-cells title='更多指引'>              
              {
                extend == '' ? null :
                  <mp-cell >
                    {extend.map((item) => (
                      <Extend key={item.extId} item={item} />
                    ))}
                  </mp-cell>
              }
              <mp-cell extClass='adds'>
                <Button className='add'>增加文字</Button><Button className='add'>增加图片</Button>
              </mp-cell>
              <mp-cell>
                <Button className='button-OK' onClick={sumbit}>确定</Button>
              </mp-cell>
            </mp-cells>
          </mp-form>
        </scroll-view>
      </view>
    </view>
  )
})